@@ -73,7 +73,8 @@ test_temp_dir <- function(pattern = "test-dir-", envir = parent.frame(),
   }
 }
 
-make_a_zip <- function(mtime = Sys.time(), envir = parent.frame()) {
+make_a_zip <- function(mtime = Sys.time(), envir = parent.frame(),
+                       include_directories = TRUE) {
   tmp <- test_temp_dir(envir = envir)
   cat("file1\n", file = file.path(tmp, "file1"))
   cat("file11\n", file = file.path(tmp, "file11"))
@@ -89,14 +90,21 @@ make_a_zip <- function(mtime = Sys.time(), envir = parent.frame()) {
   Sys.setFileTime(tmp, mtime)
 
   zip <- test_temp_file(".zip", envir = envir)
-  zipr(zip, tmp)
+  zipr(zip, tmp, include_directories = include_directories)
   list(zip = zip, ex = tmp)
 }
 
-expect_deprecated <- function(expr) {
-  expect_silent(
-    withCallingHandlers(
-      expr,
-      "deprecated" = function(e) invokeRestart("muffleMessage"))
+local_temp_dir <- function(pattern = "file", tmpdir = tempdir(),
+                           fileext = "", envir = parent.frame()) {
+  path <- tempfile(pattern = pattern, tmpdir = tmpdir, fileext = fileext)
+  dir.create(path)
+  setwd(path)
+  do.call(
+    withr::defer,
+    list(
+      bquote(unlink(.(path), recursive = TRUE)),
+      envir = envir
+    )
   )
+  invisible(path)
 }
